@@ -2,20 +2,20 @@ from Products.Five import BrowserView
 from rt.vuvuzela import vuvuzelaMessageFactory as _
 from zope.interface import implements, Interface
 
-class IvuvuzelaView(Interface):
+class IVuvuzelaView(Interface):
     """
-    vuvuzela view interface
+    Vuvuzela view interface
     """
 
     def play():
-        """ test method"""
+        """Peeeeeeeeeeee"""
 
 
-class vuvuzelaView(BrowserView):
+class VuvuzelaView(BrowserView):
     """
-    vuvuzela browser view
+    Vuvuzela browser view
     """
-    implements(IvuvuzelaView)
+    implements(IVuvuzelaView)
 
     def play(self):
         """
